package com.sundot.airport.blocked.service;

import java.util.List;

import com.sundot.airport.blocked.domain.BlockedLuggagePieceDaily;

/**
 * 每日各时段查堵行李Service接口
 *
 * @author wangxx
 * @date 2026-04-13
 */
public interface IBlockedLuggagePieceDailyService {
    /**
     * 查询每日各时段查堵行李
     *
     * @param id 每日各时段查堵行李主键
     * @return 每日各时段查堵行李
     */
    public BlockedLuggagePieceDaily selectBlockedLuggagePieceDailyById(Long id);

    /**
     * 查询每日各时段查堵行李列表
     *
     * @param blockedLuggagePieceDaily 每日各时段查堵行李
     * @return 每日各时段查堵行李集合
     */
    public List<BlockedLuggagePieceDaily> selectBlockedLuggagePieceDailyList(BlockedLuggagePieceDaily blockedLuggagePieceDaily);

    /**
     * 新增每日各时段查堵行李
     *
     * @param blockedLuggagePieceDaily 每日各时段查堵行李
     * @return 结果
     */
    public int insertBlockedLuggagePieceDaily(BlockedLuggagePieceDaily blockedLuggagePieceDaily);

    /**
     * 修改每日各时段查堵行李
     *
     * @param blockedLuggagePieceDaily 每日各时段查堵行李
     * @return 结果
     */
    public int updateBlockedLuggagePieceDaily(BlockedLuggagePieceDaily blockedLuggagePieceDaily);

    /**
     * 批量删除每日各时段查堵行李
     *
     * @param ids 需要删除的每日各时段查堵行李主键集合
     * @return 结果
     */
    public int deleteBlockedLuggagePieceDailyByIds(Long[] ids);

    /**
     * 删除每日各时段查堵行李信息
     *
     * @param id 每日各时段查堵行李主键
     * @return 结果
     */
    public int deleteBlockedLuggagePieceDailyById(Long id);

    /**
     * 导入每日各时段查堵行李数据
     *
     * @param list 数据列表
     * @param updateSupport 是否更新支持
     * @return 导入结果信息
     */
    public String importData(List<BlockedLuggagePieceDaily> list, boolean updateSupport);

    /**
     * 检查数据是否重复
     *
     * @param blockedLuggagePieceDaily 统计数据
     * @return 重复的数据，如果没有重复返回null
     */
    public BlockedLuggagePieceDaily checkDuplicate(BlockedLuggagePieceDaily blockedLuggagePieceDaily);

    /**
     * 新增或更新每日各时段查堵行李（如果数据重复则覆盖更新）
     *
     * @param blockedLuggagePieceDaily 每日各时段查堵行李
     * @return 结果
     */
    public int insertOrUpdate(BlockedLuggagePieceDaily blockedLuggagePieceDaily);
}
